/*
 * Amaze - QT downloader for the Amazon MP3 store
 * Copyright (c) 2010-2011 Robert Keevil
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DOWNLOAD_H
#define DOWNLOAD_H

#include <QObject>
#include <QMutex>
#include <QNetworkProxy>
#include <QNetworkAccessManager>
#include <QNetworkReply>
#include <QFile>
#include "common.h"
#include "amaze.h"

class Download : public QObject
{
Q_OBJECT
public:
    explicit Download(Amaze *parent);
    ~Download();

    void get_next();

private:
    Amaze *amaze;
    int track_index;

    QUrl url;
    QNetworkAccessManager *manager;
    QNetworkRequest request;
    QNetworkReply *reply;

    QFile *file;

private slots:
    void get_finished();
    void get_progress(qint64 current, qint64 total);

signals:
    void started(int track_index);
    void finished(int track_index, bool success, QString error_msg);
    void progress(int track_index, qint64 bytes_current, qint64 bytes_total);
    void add_log(LOG_LEVEL, QString);
};

#endif // DOWNLOAD_H
